#ifndef EXTERN_H
#define EXTERN_H

/* -*-C-*-
 ********************************************************************************
 *
 * File:        extern.h  (Formerly extern.h)
 * Description:  External definitions for C or C++
 * Author:       Mark Seaman, OCR Technology
 * Created:      Tue Mar 20 14:01:22 1990
 * Modified:     Tue Mar 20 14:02:09 1990 (Mark Seaman) marks@hpgrlt
 * Language:     C
 * Package:      N/A
 * Status:       Experimental (Do Not Distribute)
 *
 * (c) Copyright 1990, Hewlett-Packard Company.
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
 ** You may obtain a copy of the License at
 ** http://www.apache.org/licenses/LICENSE-2.0
 ** Unless required by applicable law or agreed to in writing, software
 ** distributed under the License is distributed on an "AS IS" BASIS,
 ** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ** See the License for the specific language governing permissions and
 ** limitations under the License.
 *
 ********************************************************************************
 */

#define EXTERN extern

#endif
